@@ -1,9 +1,9 @@
 #include <iostream>
 #include <QtGui>
 
-#include "UPlay.h"
+#include "Player.h"
 
-Engine::Engine(UPlay* parent)
+Engine::Engine(Player* parent)
 {
 	this->parent = parent;
 	
@@ -49,12 +49,18 @@ Engine::Engine(UPlay* parent)
 	
 	connect(mediaObject, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
 				    this, SLOT(currentInfosUpdated(Phonon::State, Phonon::State)));
+	
+	connect(mediaObject,SIGNAL(stateChanged(Phonon::State,Phonon::State)),
+				    this,SLOT(setInitialPosition(Phonon::State)));
 
 	listMedias.clear();
 	
 	// default value
 	currentPlayedMedia = -1;
 	lastUpdated = -1;
+	
+	init_position=0;
+	initial=false;
 }
 
 Engine::~Engine()
@@ -107,6 +113,11 @@ Engine::stop()
 int
 Engine::play(int row)
 {
+//   qDebug()<<"cur = "<<currentPlayedMedia<<" , row = "<<row;
+//   qDebug()<<"state="<<mediaObject->state();
+  
+  if(row>0) initial=false;
+  
   	if (currentPlayedMedia != -1 && row == -1)
 	{
 		switch (mediaObject->state())
@@ -122,6 +133,7 @@ Engine::play(int row)
 			case Phonon::PlayingState:
 				mediaObject->pause();
 				parent->ui->getControls().setPlayIcon(Phonon::PlayingState);
+				row = currentPlayedMedia;
 				break;
 			default:
 				break;
@@ -133,6 +145,12 @@ Engine::play(int row)
 		if (row < listMedias.count())
 		{
 
+		        int prev_media_indx=listSources.indexOf(mediaObject->currentSource());
+			if (prev_media_indx > -1)
+			{
+				parent->ui->getPlaylist().setBold(prev_media_indx,false);
+			}
+		  
 			// preparing reading
 			mediaObject->setCurrentSource(listSources[row]);
 			mediaObject->setTickInterval(1000);
@@ -140,10 +158,7 @@ Engine::play(int row)
 			currentTime->setText("0:00");
 			seekSlider->setMediaObject(mediaObject);
 
-			if (currentPlayedMedia > -1)
-			{
-				parent->ui->getPlaylist().setBold(currentPlayedMedia,false);
-			}
+
 			currentPlayedMedia = row;
 			parent->ui->getPlaylist().setBold(row,true);
 
@@ -199,7 +214,8 @@ void Engine::addMedia(QStringList files)
 
 void Engine::startMetaUpdater(bool reload)
 {
-  	if ((!listSources.isEmpty())&&(parent->config->useTags)&&(!parent->config->updateOnPlay))
+  	//if ((!listSources.isEmpty())&&(parent->config->useTags)&&(!parent->config->updateOnPlay))
+	if (!listSources.isEmpty())
 	{
 	  if(reload)
 	  {
@@ -253,45 +269,83 @@ Engine::metaInfosUpdated(Phonon::State newState, Phonon::State oldState)
 {
 	// When a file was added, and when
 	// his metadata were resolved, we can add it to the displayed playlist
+	// qDebug()<<"state "<<oldState <<"-> "<<newState <<"\t   "<<listSources.indexOf(mediaObjectForMetaInfos->currentSource());
+
 	
-	 if (newState != Phonon::StoppedState && newState != Phonon::PausedState) //
+	 if(oldState==Phonon::ErrorState)
+	 {
+	   mediaObjectForMetaInfos->setCurrentSource(mediaObjectForMetaInfos->currentSource()); //reload after error
+	   return;
+	 }
+	 
+	 if (newState != Phonon::StoppedState && newState != Phonon::PausedState && newState != Phonon::ErrorState) //
 	  return;
 	 
-	 if (mediaObjectForMetaInfos->currentSource().type() == Phonon::MediaSource::Invalid)
-          return;
-	
+	 if( mediaObjectForMetaInfos->currentSource().type() == Phonon::MediaSource::Invalid )
+	  return;
+	 
+	 Media media;
+	 QString result;
+	 
+	 if( (newState != Phonon::ErrorState) &&
+	     (parent->config->useTags)&&(!parent->config->updateOnPlay) )
+	 {
+
 	 //mediaObjectForMetaInfos
 	  QMap<QString, QString> metaData = mediaObjectForMetaInfos->metaData();
 
-	Media media;
+	  
 		// get infos
-	media.title = metaData.value("TITLE");
-	if (media.title == "")
+	  media.title = metaData.value("TITLE");
+	  if (media.title == "")
+	  {
+	    int nn=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
+	    QFileInfo fi(listUris[nn]);
+	    media.title = fi.fileName();
+	  }
+	  media.artist = metaData.value("ARTIST");
+	  media.album = metaData.value("ALBUM");
+	  media.totalTime = Engine::msToString(mediaObjectForMetaInfos->totalTime());
+	
+	  if(media.artist == "")
+	    result = media.title;
+	  else
+	    result = media.artist + " - " + media.title;
+	}
+	else
 	{
-	  int nn=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
+	  int nn = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
+
+	  //qDebug()<<nn<<" - "<<mediaObjectForMetaInfos->currentSource().type();
 	  QFileInfo fi(listUris[nn]);
 	  media.title = fi.fileName();
-	}
-	media.artist = metaData.value("ARTIST");
-	media.album = metaData.value("ALBUM");
-	media.totalTime = Engine::msToString(mediaObjectForMetaInfos->totalTime());
-	
-	QString result;
-	if(media.artist == "")
+	  media.totalTime = "";
+	  media.album = "";
+	  media.artist = "";
+	  	  
 	  result = media.title;
-	else
-	  result = media.artist + " - " + media.title;
-	
-	parent->ui->changeItem(result, listSources.indexOf(mediaObjectForMetaInfos->currentSource()));
-	listMedias.replace(listSources.indexOf(mediaObjectForMetaInfos->currentSource()),media);
-	//parent->ui->addItem(result);
-	//listMedias.append(media);
-	lastUpdated=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
-	int index = listSources.indexOf(mediaObjectForMetaInfos->currentSource()) + 1;
-	if (listSources.size() > index) 
-	{
-	  mediaObjectForMetaInfos->setCurrentSource(listSources.at(index));
 	}
+	   
+	int curr_index=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
+
+	if(curr_index>=0 && curr_index< listSources.size())
+	{
+	  if(newState != Phonon::ErrorState)
+	    parent->ui->changeItem(result, curr_index);
+	  else
+	    parent->ui->changeItem(result, curr_index,true);
+	
+	
+	  listMedias.replace(curr_index,media);
+	  //parent->ui->addItem(result);
+	  //listMedias.append(media);
+	  lastUpdated=curr_index;
+	  int index = curr_index + 1;
+	  if (listSources.size() > index) 
+	  {
+	    mediaObjectForMetaInfos->setCurrentSource(listSources.at(index));
+	  }
+	 }
 
 }
 
@@ -299,7 +353,7 @@ void Engine::currentInfosUpdated(Phonon::State newState, Phonon::State oldState)
 {
    //qDebug()<<"=======>oldState: "<<oldState;
    //qDebug()<<"=======>newState: "<<newState;
-  if (newState == Phonon::PlayingState )
+  if (newState == Phonon::PlayingState || newState == Phonon::PausedState)
   {
     totalTime->setText(" / " + Engine::msToString(mediaObject->totalTime()));
   
@@ -352,7 +406,10 @@ void Engine::currentInfosUpdated(Phonon::State newState, Phonon::State oldState)
     
   }
   
-  
+  if (newState == Phonon::ErrorState) //in case of bad file : skip
+  {
+    parent->next();
+  }
   //mediaObject
   
 }
@@ -379,6 +436,49 @@ Engine::delMedia(int row)
 	return ret;
 }
 
+int Engine::moveMedia(int row, bool moveUp)
+{
+  int moved=0;
+  Media tmpMedia;
+  Phonon::MediaSource tmpSource;
+  QString tmpUri;
+  
+  if((row>0)&&(moveUp))
+  {
+    tmpMedia=listMedias.at(row);
+    tmpSource=listSources.at(row);
+    tmpUri=listUris.at(row);
+    
+    listMedias.replace(row,listMedias.at(row-1));
+    listSources.replace(row,listSources.at(row-1));
+    listUris.replace(row,listUris.at(row-1));
+    
+    listMedias.replace(row-1,tmpMedia);
+    listSources.replace(row-1,tmpSource);
+    listUris.replace(row-1,tmpUri);
+    moved=1;
+  }
+  
+  if((row<listMedias.count()-1)&&(!moveUp))
+  {
+    tmpMedia=listMedias.at(row);
+    tmpSource=listSources.at(row);
+    tmpUri=listUris.at(row);
+    
+    listMedias.replace(row,listMedias.at(row+1));
+    listSources.replace(row,listSources.at(row+1));
+    listUris.replace(row,listUris.at(row+1));
+    
+    listMedias.replace(row+1,tmpMedia);
+    listSources.replace(row+1,tmpSource);
+    listUris.replace(row+1,tmpUri); 
+    moved=-1;
+  }
+  
+  return moved;
+  
+}
+
 void
 Engine::clearPlayList()
 {
@@ -441,3 +541,63 @@ Engine::msToString(qint64 ms)
 	return ret;
 }
 
+void Engine::setInitialPosition(Phonon::State state)
+{
+ // qDebug()<<"State: "<<state;
+
+  
+  
+  if((initial)&&(state==Phonon::PlayingState))
+  {
+    initial=false;
+
+    mediaObject->seek(init_position);   
+  }
+    if((initial)&&(state==Phonon::PausedState))
+  {
+    mediaObject->seek(init_position);
+  }
+  
+  
+  
+}
+
+void Engine::restoreState(int row, qint64 time)
+{
+  //qDebug()<<row<<" :::: "<<time;
+  if(row < listMedias.count())
+  {
+    //qDebug()<<listSources.size();
+    mediaObject->setCurrentSource(listSources[row]);
+    mediaObject->setTickInterval(1000);
+    mediaObject->setTransitionTime(1000);
+    currentTime->setText("0:00");
+    seekSlider->setMediaObject(mediaObject);
+  
+    currentPlayedMedia=row;
+  
+    parent->ui->getPlaylist().setBold(row,true);
+
+    mediaObject->pause();
+    parent->ui->getControls().setPlayIcon(Phonon::PlayingState);
+    
+    initial=true;
+    init_position=time;
+   
+ 
+   
+  }	  
+}
+
+
+int Engine::getCurrentPlayedMedia()
+{
+  int media_indx=listSources.indexOf(mediaObject->currentSource());
+  return media_indx;
+}
+
+int Engine::getNUris()
+{
+  return listUris.size();
+  
+}
\ No newline at end of file
