@@ -1,15 +1,17 @@
 #include <iostream>
 #include <QtGui>
 
-#include "UPlay.h"
+#include "Player.h"
 #include "UI.h"
 
-UI::UI(UPlay* parent, QString& musicPath)
+UI::UI(Player* parent, QString& musicPath)
 {
 	this->parent = parent;
 	
 	setupActions();
 	setupMenus();
+	
+	workdir=QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
 
 	//QStyle* style = this->style();
 
@@ -90,6 +92,9 @@ UI::UI(UPlay* parent, QString& musicPath)
 	
 	settingsdialog = new SettingsDialog();
 	connect(settingsdialog, SIGNAL(accepted()), this, SLOT(settingsDialogAccepted()));
+	
+	urldialog = new UrlDialog();
+	connect(urldialog, SIGNAL(accepted()), this, SLOT(urlDialogAccepted()));
 
 	setWindowTitle("NecroPlayer");
 	show();
@@ -159,9 +164,9 @@ UI::addItem(QString s)
 	playlist->addItem(s);
 }
 
-void UI::changeItem(QString s, int row)
+void UI::changeItem(QString s, int row, bool disabled)
 {
-	playlist->changeItem(s,row);
+	playlist->changeItem(s,row,disabled);
 }
 
 void
@@ -200,11 +205,26 @@ void UI::setupActions()
   settingsAction = new QAction(tr("Settings"),this);
   connect(settingsAction, SIGNAL(triggered()), this, SLOT(settingsDialogOpen()));
   
+  loadPlaylist =  new QAction(tr("Load Playlist"),this);
+  connect(loadPlaylist, SIGNAL(triggered()), this, SLOT(loadPlaylistDialog()));
+  
+  savePlaylist =  new QAction(tr("Save Playlist"),this);
+  connect(savePlaylist, SIGNAL(triggered()), this, SLOT(savePlaylistDialog()));
+  
+  openUrl = new QAction(tr("Open Url"),this);
+  connect(openUrl, SIGNAL(triggered()), this, SLOT(openUrlDialog()));
+  
+  
   
 }
 
 void UI::setupMenus()
 {
+  fileMenu = menuBar()->addMenu(tr("File"));
+  fileMenu->addAction(loadPlaylist);
+  fileMenu->addAction(savePlaylist);
+  fileMenu->addAction(openUrl);
+  
   settingsMenu = menuBar()->addMenu(tr("Settings"));
   settingsMenu->addAction(settingsAction);
   
@@ -213,7 +233,7 @@ void UI::setupMenus()
 void UI::settingsDialogOpen()
 {
   settingsdialog->setConfig(parent->config);
-  settingsdialog->show();
+  settingsdialog->exec();
   
 }
 
@@ -222,15 +242,75 @@ void UI::settingsDialogAccepted()
   //qDebug()<<"Setting Dialog Accepted";
   bool tmpUseTags=parent->config->useTags;
   bool tmpUpdateOnPlay=parent->config->updateOnPlay;
+  QString tmpFolder=parent->config->musicFolder;
   settingsdialog->getConfig(parent->config);
-  if(((tmpUseTags==false)&&(parent->config->useTags==true))||
-   ((tmpUpdateOnPlay==true)&&(parent->config->updateOnPlay==false)&&(parent->config->useTags==true)))
+  //if(((tmpUseTags==false)&&(parent->config->useTags==true))||
+  // ((tmpUpdateOnPlay==true)&&(parent->config->updateOnPlay==false)&&(parent->config->useTags==true)))
+  if((tmpUseTags!=parent->config->useTags)||(tmpUpdateOnPlay!=parent->config->updateOnPlay))
     parent->engine->startMetaUpdater(true);
   
-  folder->refreshWithNewMusicPath(parent->config->musicFolder);
+  if(tmpFolder!=parent->config->musicFolder)
+    folder->refreshWithNewMusicPath(parent->config->musicFolder);
   
   
 }
 
+void UI::loadPlaylistDialog()
+{
 
+  QString tmpfile;
+  
+  tmpfile=QFileDialog::getOpenFileName(this,tr("Open Playlist"),workdir,
+				       tr("Playlist files ( *.m3u *.M3U *.pls *.PLS)"));
+  
+  if(!tmpfile.isNull())
+  {
+    if(tmpfile.endsWith(".m3u",Qt::CaseInsensitive))
+    {
+      parent->restorePlaylist(tmpfile);
+    }
+    else
+    {
+      parent->openPlaylist_pls(tmpfile);
+    }
+    
+    parent->engine->startMetaUpdater();
+    
+    QFileInfo tmpinfo(tmpfile);
+    workdir=tmpinfo.dir().absolutePath();
+  }
+}
+
+void UI::savePlaylistDialog()
+{
+  QString tmpfile;
+  
+  tmpfile=QFileDialog::getSaveFileName(this,tr("Save Playlist"),workdir,
+					tr("Playlist files ( *.m3u *.M3U)"));
+  
+  if(!tmpfile.isNull())
+  {
+    parent->savePlaylist(tmpfile);  
+    QFileInfo tmpinfo(tmpfile);
+    workdir=tmpinfo.dir().absolutePath();
+  }
+}
+
+void UI::openUrlDialog()
+{
+  urldialog->setUrl("");
+  urldialog->exec();
+}
+
+void UI::urlDialogAccepted()
+{
+  QString tmpstr=urldialog->getUrl();
+  if(!tmpstr.isNull())
+  {
+    QStringList tmplist;
+    tmplist.append(tmpstr);
+    playlistAdd(tmplist);
+ 
+  } 
+}
 
