@@ -4,7 +4,7 @@
 #include <QtCore>
 #include <QtGui>
 
-class UPlay;
+class Player;
 
 class UIPlaylist : public QWidget
 {
@@ -13,7 +13,7 @@ class UIPlaylist : public QWidget
 		/*
 		 * Constructor
 		 */
-		UIPlaylist(UPlay* parent);
+		UIPlaylist(Player* parent);
 		
 		~UIPlaylist();
 
@@ -30,14 +30,18 @@ class UIPlaylist : public QWidget
 		 */
 		int currentRow()
 		{
-			return widgetPlaylist->currentRow();
+		  return widgetPlaylist->currentRow();
 		}
+// 		void setCurrentRow(int row)
+// 		{
+// 		  widgetPlaylist->setCurrentRow(row);
+// 		}
 
 		/*
 		 * Add a media in the playlist
 		 */
 		void addItem(QString s);
-		void changeItem(QString s,int row);
+		void changeItem(QString s,int row,bool disabled=false);
 
 		/*
 		 * Set bold/Unbold a row of the playlist
@@ -50,14 +54,17 @@ class UIPlaylist : public QWidget
 		void playlistDoubleClicked();
 		void savePlaylist();
 		void delItem();
+		void upItem();
+		void downItem();
 
 	private:
 		QListWidget* widgetPlaylist;
-		QPushButton* buttonDel, *buttonSave, *buttonClear;
+		QPushButton* buttonDel, *buttonClear;
+		QPushButton* buttonUp, *buttonDown;
 		QHBoxLayout* layoutControlPL;
 		QVBoxLayout* layout;
 
-		UPlay* parent;
+		Player* parent;
 };
 
 #endif // UIPLAYLIST_H
