@@ -54,55 +54,100 @@
         <translation>Проигрываемое</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
         <source>Save playlist on quit</source>
-        <translation>Сохранять список при выходе</translation>
+        <translation type="obsolete">Сохранять список при выходе</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="76"/>
+        <location filename="../src/SettingsDialog.cpp" line="67"/>
+        <source>Save playing position on quit</source>
+        <translation>Сохранять позицию при выходе</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="80"/>
         <source>Music Directory</source>
         <translation>Директория с музыкой</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="83"/>
+        <location filename="../src/SettingsDialog.cpp" line="87"/>
         <source>Directory:</source>
         <translation>Директория:</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="91"/>
+        <location filename="../src/SettingsDialog.cpp" line="95"/>
         <source>Browse</source>
         <translation>Выбрать</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="98"/>
+        <location filename="../src/SettingsDialog.cpp" line="102"/>
         <source>Show hidden files</source>
         <translation>Показывать скрытые файлы</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="118"/>
+        <location filename="../src/SettingsDialog.cpp" line="122"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="181"/>
+        <source>Select your music directory</source>
+        <translation>Выбор директории с музыкой</translation>
+    </message>
 </context>
 <context>
     <name>UI</name>
     <message>
-        <location filename="../src/UI.cpp" line="48"/>
+        <location filename="../src/UI.cpp" line="50"/>
         <source>Playlist</source>
         <translation>Список</translation>
     </message>
     <message>
-        <location filename="../src/UI.cpp" line="49"/>
+        <location filename="../src/UI.cpp" line="51"/>
         <source>Files</source>
         <translation>Файлы</translation>
     </message>
+    <message>
+        <location filename="../src/UI.cpp" line="208"/>
+        <source>Load Playlist</source>
+        <translation>Загрузить список</translation>
+    </message>
+    <message>
+        <location filename="../src/UI.cpp" line="211"/>
+        <location filename="../src/UI.cpp" line="288"/>
+        <source>Save Playlist</source>
+        <translation>Сохранить список</translation>
+    </message>
+    <message>
+        <location filename="../src/UI.cpp" line="214"/>
+        <source>Open Url</source>
+        <translation>Открыть адрес</translation>
+    </message>
+    <message>
+        <location filename="../src/UI.cpp" line="223"/>
+        <source>File</source>
+        <translation>Файл</translation>
+    </message>
+    <message>
+        <location filename="../src/UI.cpp" line="263"/>
+        <source>Open Playlist</source>
+        <translation>Открыть список</translation>
+    </message>
+    <message>
+        <location filename="../src/UI.cpp" line="264"/>
+        <source>Playlist files ( *.m3u *.M3U *.pls *.PLS)</source>
+        <translation>Списки ( *.m3u *.M3U *.pls *.PLS)</translation>
+    </message>
+    <message>
+        <location filename="../src/UI.cpp" line="289"/>
+        <source>Playlist files ( *.m3u *.M3U)</source>
+        <translation>Списки ( *.m3u *.M3U)</translation>
+    </message>
     <message>
         <source>Folder</source>
         <translation type="obsolete">Директория</translation>
     </message>
     <message>
-        <location filename="../src/UI.cpp" line="200"/>
-        <location filename="../src/UI.cpp" line="208"/>
+        <location filename="../src/UI.cpp" line="205"/>
+        <location filename="../src/UI.cpp" line="228"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
@@ -131,19 +176,24 @@
 <context>
     <name>UIPlaylist</name>
     <message>
-        <location filename="../src/UIPlaylist.cpp" line="12"/>
         <source>Remove</source>
-        <translation>Удалить</translation>
+        <translation type="obsolete">Удалить</translation>
     </message>
     <message>
-        <location filename="../src/UIPlaylist.cpp" line="15"/>
         <source>Clear</source>
-        <translation>Очистить</translation>
+        <translation type="obsolete">Очистить</translation>
     </message>
     <message>
-        <location filename="../src/UIPlaylist.cpp" line="18"/>
         <source>Save</source>
-        <translation>Сохранить</translation>
+        <translation type="obsolete">Сохранить</translation>
+    </message>
+</context>
+<context>
+    <name>UrlDialog</name>
+    <message>
+        <location filename="../src/UrlDialog.cpp" line="21"/>
+        <source>Url</source>
+        <translation>Адрес</translation>
     </message>
 </context>
 </TS>
